@@ -1,12 +1,12 @@
 package Encode::JP::Mobile;
-our $VERSION = "0.18";
+our $VERSION = "0.19";
 
 use Encode;
 use XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
 
 use base qw( Exporter );
-@EXPORT_OK = qw( InDoCoMoPictograms InKDDIPictograms InSoftBankPictograms InAirEdgePictograms InMobileJPPictograms );
+@EXPORT_OK = qw( InDoCoMoPictograms InKDDIPictograms InSoftBankPictograms InAirEdgePictograms InMobileJPPictograms InKDDISoftBankConflicts);
 %EXPORT_TAGS = ( props => [@EXPORT_OK] );
 
 use Encode::Alias;
@@ -93,6 +93,12 @@ sub InMobileJPPictograms {
     return join "\n", InDoCoMoPictograms, InKDDIPictograms, InSoftBankPictograms, InAirEdgePictograms;
 }
 
+sub InKDDISoftBankConflicts {
+    return <<END;
+E501\tE537
+END
+}
+
 1;
 
 =encoding utf-8
@@ -239,12 +245,27 @@ AirEDGE の絵文字をマッピングします。cp932 の完全なサブセッ
 
 =item InAirEdgePictograms
 
+=item InKDDISoftBankConflicts
+
 =back
 
 InKDDIPictograms はCP932ベースと裏KDDI Unicodeの双方を含みます。
 
 入力が Shift_JIS である場合、まずどの x-sjis-* に対応するかを判別した上でデコードし、Unicode コードポイントを得たあとでないとキャリアを見分けることができません。よって入力が UTF-8 である場合や、いったん x-sjis-* を利用してデコードしたものに対して使うと便利でしょう。
 
+InKDDISoftBankConflicts は SoftBank と KDDI (x-sjis-kddi を利用した場合) の Unicode 私用領域の重複する文字列を含んでいます。以下のようなコードで、元々の絵文字が KDDI のものであったか、SoftBank のものであったか判定することが可能です（文字列に含まれる絵文字が重複部分のみの場合、判定することはできません）。
+
+  my $string = ...;
+
+  if ($string =~ /\p{InKDDISoftBankConflicts}/) {
+      eval { Encode::encode("x-sjis-kddi", $string, Encode::FB_CROAK) };
+      if ($@) {
+          # softbank
+      } else {
+          # KDDI
+      }
+  }
+
 =head1 BACKWARD COMPATIBLITY
 
 バージョン 0.07 から、モジュールで利用するエンコーディング名を I<x-sjis-*> のように変更しました。以前の I<shift_jis-*> というエイリアスも残してありますが、将来のリリースで削除される予定です。
